@@ -28,7 +28,7 @@ from gettext import gettext as _
 import threading
 import string
 import re
-import random
+from random import randint
 
 import dialogs
 from softwareproperties.MirrorTest import MirrorTest
@@ -304,24 +304,6 @@ class DialogMirror:
             frac = borders[0] + (borders[1] - borders[0]) / max * current
             self.progress.set_fraction(frac)
             gtk.gdk.threads_leave()
-        def run_full_test(self):
-            # Determinate the 5 top ping servers
-            results_ping = self.run_ping_test(max=5,
-                                              borders=(0, 0.5),
-                                              mod=(0,7))
-            # Add two random mirrors to the download test
-            results_ping.append([0, 0, self.mirrors[random.randint(1, len(self.mirrors))]])
-            results_ping.append([0, 0, self.mirrors[random.randint(1, len(self.mirrors))]])
-            results = self.run_download_test(map(lambda r: r[2], results_ping),
-                                             borders=(0.5, 1),
-                                             mod=(MirrorTest.todo,
-                                                  MirrorTest.todo))
-            for (t, h) in results:
-                print "mirror: %s - time: %s" % (h.hostname, t)
-            if len(results) == 0:
-                return None
-            else:
-                return results[0][1].hostname
 
     gtk.gdk.threads_enter()
     self.button_cancel.set_sensitive(True)
